@@ -26,9 +26,7 @@ from novaclient import utils
 
 
 class Flavor(base.Resource):
-    """
-    A flavor is an available hardware configuration for a server.
-    """
+    """A flavor is an available hardware configuration for a server."""
     HUMAN_ID = True
 
     def __repr__(self):
@@ -36,29 +34,22 @@ class Flavor(base.Resource):
 
     @property
     def ephemeral(self):
-        """
-        Provide a user-friendly accessor to OS-FLV-EXT-DATA:ephemeral
-        """
+        """Provide a user-friendly accessor to OS-FLV-EXT-DATA:ephemeral."""
         return self._info.get("OS-FLV-EXT-DATA:ephemeral", 'N/A')
 
     @property
     def is_public(self):
-        """
-        Provide a user-friendly accessor to os-flavor-access:is_public
-        """
+        """Provide a user-friendly accessor to os-flavor-access:is_public."""
         return self._info.get("os-flavor-access:is_public", 'N/A')
 
     def get_keys(self):
-        """
-        Get extra specs from a flavor.
-        """
+        """Get extra specs from a flavor."""
         _resp, body = self.manager.api.client.get(
             "/flavors/%s/os-extra_specs" % base.getid(self))
         return body["extra_specs"]
 
     def set_keys(self, metadata):
-        """
-        Set extra specs on a flavor.
+        """Set extra specs on a flavor.
 
         :param metadata: A dict of key/value pairs to be set
         """
@@ -70,8 +61,7 @@ class Flavor(base.Resource):
             "extra_specs", return_raw=True)
 
     def unset_keys(self, keys):
-        """
-        Unset extra specs on a flavor.
+        """Unset extra specs on a flavor.
 
         :param keys: A list of keys to be unset
         """
@@ -80,30 +70,30 @@ class Flavor(base.Resource):
                 "/flavors/%s/os-extra_specs/%s" % (base.getid(self), k))
 
     def delete(self):
-        """
-        Delete this flavor.
-        """
+        """Delete this flavor."""
         self.manager.delete(self)
 
 
 class FlavorManager(base.ManagerWithFind):
-    """
-    Manage :class:`Flavor` resources.
-    """
+    """Manage :class:`Flavor` resources."""
     resource_class = Flavor
     is_alphanum_id_allowed = True
 
     def list(self, detailed=True, is_public=True, marker=None, limit=None,
              sort_key=None, sort_dir=None):
-        """
-        Get a list of all flavors.
+        """Get a list of all flavors.
 
-        :rtype: list of :class:`Flavor`.
-        :param limit: maximum number of flavors to return (optional).
+        :param detailed: Whether flavor needs to be return with details
+                         (optional).
+        :param is_public: Filter flavors with provided access type (optional).
+                          None means give all flavors and only admin has query
+                          access to all flavor types.
         :param marker: Begin returning flavors that appear later in the flavor
                        list than that represented by this flavor id (optional).
+        :param limit: maximum number of flavors to return (optional).
         :param sort_key: Flavors list sort key (optional).
         :param sort_dir: Flavors list sort direction (optional).
+        :returns: list of :class:`Flavor`.
         """
         qparams = {}
         # is_public is ternary - None means give all flavors.
@@ -129,17 +119,15 @@ class FlavorManager(base.ManagerWithFind):
         return self._list("/flavors%s%s" % (detail, query_string), "flavors")
 
     def get(self, flavor):
-        """
-        Get a specific flavor.
+        """Get a specific flavor.
 
         :param flavor: The ID of the :class:`Flavor` to get.
-        :rtype: :class:`Flavor`
+        :returns: :class:`Flavor`
         """
         return self._get("/flavors/%s" % base.getid(flavor), "flavor")
 
     def delete(self, flavor):
-        """
-        Delete a specific flavor.
+        """Delete a specific flavor.
 
         :param flavor: The ID of the :class:`Flavor` to get.
         """
@@ -163,8 +151,7 @@ class FlavorManager(base.ManagerWithFind):
 
     def create(self, name, ram, vcpus, disk, flavorid="auto",
                ephemeral=0, swap=0, rxtx_factor=1.0, is_public=True):
-        """
-        Create a flavor.
+        """Create a flavor.
 
         :param name: Descriptive name of the flavor
         :param ram: Memory in MB for the flavor
@@ -175,7 +162,7 @@ class FlavorManager(base.ManagerWithFind):
                          flavor in cases where you cannot simply pass ``None``.
         :param swap: Swap space in MB
         :param rxtx_factor: RX/TX factor
-        :rtype: :class:`Flavor`
+        :returns: :class:`Flavor`
         """
 
         try:
