@@ -14,15 +14,17 @@
 #    under the License.
 
 """
-Volume snapshot interface (1.1 extension).
+DEPRECATED: Volume snapshot interface (1.1 extension).
 """
 
+import warnings
+
 from novaclient import base
 
 
 class Snapshot(base.Resource):
     """
-    A Snapshot is a point-in-time snapshot of an openstack volume.
+    DEPRECATED: A Snapshot is a point-in-time snapshot of an openstack volume.
     """
     NAME_ATTR = 'display_name'
 
@@ -31,14 +33,14 @@ class Snapshot(base.Resource):
 
     def delete(self):
         """
-        Delete this snapshot.
+        DEPRECATED: Delete this snapshot.
         """
         self.manager.delete(self)
 
 
 class SnapshotManager(base.ManagerWithFind):
     """
-    Manage :class:`Snapshot` resources.
+    DEPRECATED: Manage :class:`Snapshot` resources.
     """
     resource_class = Snapshot
 
@@ -46,16 +48,21 @@ class SnapshotManager(base.ManagerWithFind):
                display_description=None):
 
         """
-        Create a snapshot of the given volume.
+        DEPRECATED: Create a snapshot of the given volume.
 
         :param volume_id: The ID of the volume to snapshot.
         :param force: If force is True, create a snapshot even if the volume is
-        attached to an instance. Default is False.
+                      attached to an instance. Default is False.
         :param display_name: Name of the snapshot
         :param display_description: Description of the snapshot
         :rtype: :class:`Snapshot`
         """
-        with self.alternate_service_type('volume'):
+        warnings.warn('The novaclient.v2.volume_snapshots module is '
+                      'deprecated and will be removed after Nova 13.0.0 is '
+                      'released. Use python-cinderclient or '
+                      'python-openstacksdk instead.', DeprecationWarning)
+        with self.alternate_service_type(
+                'volumev2', allowed_types=('volume', 'volumev2')):
             body = {'snapshot': {'volume_id': volume_id,
                                  'force': force,
                                  'display_name': display_name,
@@ -64,21 +71,32 @@ class SnapshotManager(base.ManagerWithFind):
 
     def get(self, snapshot_id):
         """
-        Get a snapshot.
+        DEPRECATED: Get a snapshot.
 
         :param snapshot_id: The ID of the snapshot to get.
         :rtype: :class:`Snapshot`
         """
-        with self.alternate_service_type('volume'):
+        warnings.warn('The novaclient.v2.volume_snapshots module is '
+                      'deprecated and will be removed after Nova 13.0.0 is '
+                      'released. Use python-cinderclient or '
+                      'python-openstacksdk instead.', DeprecationWarning)
+        with self.alternate_service_type(
+                'volumev2', allowed_types=('volume', 'volumev2')):
+
             return self._get("/snapshots/%s" % snapshot_id, "snapshot")
 
     def list(self, detailed=True):
         """
-        Get a list of all snapshots.
+        DEPRECATED: Get a list of all snapshots.
 
         :rtype: list of :class:`Snapshot`
         """
-        with self.alternate_service_type('volume'):
+        warnings.warn('The novaclient.v2.volume_snapshots module is '
+                      'deprecated and will be removed after Nova 13.0.0 is '
+                      'released. Use python-cinderclient or '
+                      'python-openstacksdk instead.', DeprecationWarning)
+        with self.alternate_service_type(
+                'volumev2', allowed_types=('volume', 'volumev2')):
             if detailed is True:
                 return self._list("/snapshots/detail", "snapshots")
             else:
@@ -86,9 +104,14 @@ class SnapshotManager(base.ManagerWithFind):
 
     def delete(self, snapshot):
         """
-        Delete a snapshot.
+        DEPRECATED: Delete a snapshot.
 
         :param snapshot: The :class:`Snapshot` to delete.
         """
-        with self.alternate_service_type('volume'):
+        warnings.warn('The novaclient.v2.volume_snapshots module is '
+                      'deprecated and will be removed after Nova 13.0.0 is '
+                      'released. Use python-cinderclient or '
+                      'python-openstacksdk instead.', DeprecationWarning)
+        with self.alternate_service_type(
+                'volumev2', allowed_types=('volume', 'volumev2')):
             self._delete("/snapshots/%s" % base.getid(snapshot))
